@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-use IO::All;
+use IO::All qw/ io /;
 
 my ($version) =
     ( map { m{\Aversion *= *(\S+)\n?\z} ? ($1) : () }
